@@ -30,6 +30,7 @@
 from __future__ import print_function
 
 import io
+import os
 import sys
 import requests
 from argparse import ArgumentParser
@@ -823,6 +824,11 @@ class DB_Importer (Log_Mixin) :
             # Add grid if available
             if a.dict.get ('gridsquare') and not qsl ['gridsquare'] :
                 qsl_dict ['gridsquare'] = a.gridsquare
+            # Add rst_sent (= qsl.rst_rcvd) if available
+            # The log (from eqsl at least) if from the perspective of
+            # the qso partner.
+            if a.dict.get ('rst_sent') and not qsl ['rst_rcvd'] :
+                qsl_dict ['rst_rcvd'] = a.rst_sent
             # Add QSL Card from eQSL
             if getattr (self.logbook, 'get_qslcard', 0) and not qsl ['files'] :
                 content = self.logbook.get_qslcard (a, self.args.eqsl_username)
@@ -932,6 +938,7 @@ class DB_Importer (Log_Mixin) :
 def main () :
     methods = [x [3:] for x in DB_Importer.__dict__ if x.startswith ('do_')]
     qsl_types = ['LOTW', 'eQSL']
+    default_url = os.environ.get ('WBF_DBURL', 'http://bee.priv.zoo:8080/qso/')
     cmd = ArgumentParser ()
     cmd.add_argument \
         ( "command"
@@ -1032,7 +1039,7 @@ def main () :
     cmd.add_argument \
         ( "-U", "--url"
         , help    = "URL of tracker (without rest path) default: %(default)s"
-        , default = 'http://bee.priv.zoo:8080/qso/'
+        , default = default_url
         )
     cmd.add_argument \
         ( "-u", "--username"
